Class: Google::Apis::StsV1::GoogleIdentityStsV1ExchangeTokenResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sts_v1/classes.rb,
lib/google/apis/sts_v1/representations.rb,
lib/google/apis/sts_v1/representations.rb

Overview

Response message for ExchangeToken.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleIdentityStsV1ExchangeTokenResponse

Returns a new instance of GoogleIdentityStsV1ExchangeTokenResponse.



401
402
403
# File 'lib/google/apis/sts_v1/classes.rb', line 401

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_boundary_session_keyString

The access boundary session key. This key is used along with the access boundary intermediary token to generate Credential Access Boundary tokens at client side. This field is absent when the requested_token_type from the request is not urn:ietf:params:oauth:token-type: access_boundary_intermediary_token. Corresponds to the JSON property access_boundary_session_key NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


371
372
373
# File 'lib/google/apis/sts_v1/classes.rb', line 371

def access_boundary_session_key
  @access_boundary_session_key
end

#access_tokenString

An OAuth 2.0 security token, issued by Google, in response to the token exchange request. Tokens can vary in size, depending in part on the size of mapped claims, up to a maximum of 12288 bytes (12 KB). Google reserves the right to change the token size and the maximum length at any time. Corresponds to the JSON property access_token

Returns:

  • (String)


379
380
381
# File 'lib/google/apis/sts_v1/classes.rb', line 379

def access_token
  @access_token
end

#expires_inFixnum

The amount of time, in seconds, between the time when the access token was issued and the time when the access token will expire. This field is absent when the subject_token in the request is a a short-lived access token for a Cloud Identity or Google Workspace user account. In this case, the access token has the same expiration time as the subject_token. Corresponds to the JSON property expires_in

Returns:

  • (Fixnum)


388
389
390
# File 'lib/google/apis/sts_v1/classes.rb', line 388

def expires_in
  @expires_in
end

#issued_token_typeString

The token type. Always matches the value of requested_token_type from the request. Corresponds to the JSON property issued_token_type

Returns:

  • (String)


394
395
396
# File 'lib/google/apis/sts_v1/classes.rb', line 394

def issued_token_type
  @issued_token_type
end

#token_typeString

The type of access token. Always has the value Bearer. Corresponds to the JSON property token_type

Returns:

  • (String)


399
400
401
# File 'lib/google/apis/sts_v1/classes.rb', line 399

def token_type
  @token_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



406
407
408
409
410
411
412
# File 'lib/google/apis/sts_v1/classes.rb', line 406

def update!(**args)
  @access_boundary_session_key = args[:access_boundary_session_key] if args.key?(:access_boundary_session_key)
  @access_token = args[:access_token] if args.key?(:access_token)
  @expires_in = args[:expires_in] if args.key?(:expires_in)
  @issued_token_type = args[:issued_token_type] if args.key?(:issued_token_type)
  @token_type = args[:token_type] if args.key?(:token_type)
end