Class: Google::Apis::StsV1::GoogleIdentityStsV1Options

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sts_v1/classes.rb,
lib/google/apis/sts_v1/representations.rb,
lib/google/apis/sts_v1/representations.rb

Overview

An Options object configures features that the Security Token Service supports, but that are not supported by standard OAuth 2.0 token exchange endpoints, as defined in https://tools.ietf.org/html/rfc8693.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleIdentityStsV1Options

Returns a new instance of GoogleIdentityStsV1Options.



577
578
579
# File 'lib/google/apis/sts_v1/classes.rb', line 577

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_boundaryGoogle::Apis::StsV1::GoogleIdentityStsV1AccessBoundary

An access boundary defines the upper bound of what a principal may access. It includes a list of access boundary rules that each defines the resource that may be allowed as well as permissions that may be used on those resources. Corresponds to the JSON property accessBoundary



560
561
562
# File 'lib/google/apis/sts_v1/classes.rb', line 560

def access_boundary
  @access_boundary
end

#bind_cert_fingerprintString

The unpadded, url-escaped, base64-encoded SHA-256 hash of the certificate's DER encoding. It must be 43 characters long. The resulting token will be bound to this value. Corresponds to the JSON property bindCertFingerprint

Returns:

  • (String)


567
568
569
# File 'lib/google/apis/sts_v1/classes.rb', line 567

def bind_cert_fingerprint
  @bind_cert_fingerprint
end

#user_projectString

A Google project used for quota and billing purposes when the credential is used to access Google APIs. The provided project overrides the project bound to the credential. The value must be a project number or a project ID. Example: my-sample-project-191923. The maximum length is 32 characters. Corresponds to the JSON property userProject

Returns:

  • (String)


575
576
577
# File 'lib/google/apis/sts_v1/classes.rb', line 575

def user_project
  @user_project
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



582
583
584
585
586
# File 'lib/google/apis/sts_v1/classes.rb', line 582

def update!(**args)
  @access_boundary = args[:access_boundary] if args.key?(:access_boundary)
  @bind_cert_fingerprint = args[:bind_cert_fingerprint] if args.key?(:bind_cert_fingerprint)
  @user_project = args[:user_project] if args.key?(:user_project)
end