Class: Google::Apis::StsV1::GoogleIdentityStsV1betaAccessBoundary
- Inherits:
-
Object
- Object
- Google::Apis::StsV1::GoogleIdentityStsV1betaAccessBoundary
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sts_v1/classes.rb,
lib/google/apis/sts_v1/representations.rb,
lib/google/apis/sts_v1/representations.rb
Overview
An access boundary defines the upper bound of what a principal may access. It includes a list of access boundary rules that each defines the resource that may be allowed as well as permissions that may be used on those resources.
Instance Attribute Summary collapse
-
#access_boundary_rules ⇒ Array<Google::Apis::StsV1::GoogleIdentityStsV1betaAccessBoundaryRule>
A list of access boundary rules which defines the upper bound of the permission a principal may carry.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleIdentityStsV1betaAccessBoundary
constructor
A new instance of GoogleIdentityStsV1betaAccessBoundary.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleIdentityStsV1betaAccessBoundary
Returns a new instance of GoogleIdentityStsV1betaAccessBoundary.
469 470 471 |
# File 'lib/google/apis/sts_v1/classes.rb', line 469 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_boundary_rules ⇒ Array<Google::Apis::StsV1::GoogleIdentityStsV1betaAccessBoundaryRule>
A list of access boundary rules which defines the upper bound of the
permission a principal may carry. If multiple rules are specified, the
effective access boundary is the union of all the access boundary rules
attached. One access boundary can contain at most 10 rules.
Corresponds to the JSON property accessBoundaryRules
467 468 469 |
# File 'lib/google/apis/sts_v1/classes.rb', line 467 def access_boundary_rules @access_boundary_rules end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
474 475 476 |
# File 'lib/google/apis/sts_v1/classes.rb', line 474 def update!(**args) @access_boundary_rules = args[:access_boundary_rules] if args.key?(:access_boundary_rules) end |