Class: Google::Apis::StsV1::GoogleIdentityStsV1OpenIdProviderConfig
- Inherits:
-
Object
- Object
- Google::Apis::StsV1::GoogleIdentityStsV1OpenIdProviderConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sts_v1/classes.rb,
lib/google/apis/sts_v1/representations.rb,
lib/google/apis/sts_v1/representations.rb
Overview
Response message for GetOpenIdProviderConfig. Message fields are defined in https://openid.net/specs/openid-connect-discovery-1_0.html# ProviderConfigurationResponse
Instance Attribute Summary collapse
-
#authorization_endpoint ⇒ String
URL pointing to an authorization endpoint under this issuer.
-
#id_token_signing_alg_values_supported ⇒ Array<String>
JSON array containing a list of the JWS signing algorithms (alg values) supported by the OP for the ID token to encode the claims in a JWT [JWT].
-
#issuer ⇒ String
URL using the https scheme with no query or fragment components that the OP asserts as its issuer identifier.
-
#jwks_uri ⇒ String
URL of the OP's JWK Set [JWK] document, which MUST use the https scheme.
-
#response_types_supported ⇒ Array<String>
JSON array containing a list of the OAuth 2.0 response_type values that this OP supports.
-
#subject_types_supported ⇒ Array<String>
JSON array containing a list of the subject identifier types that this OP supports.
-
#token_endpoint ⇒ String
URL pointing to a token endpoint under this issuer.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleIdentityStsV1OpenIdProviderConfig
constructor
A new instance of GoogleIdentityStsV1OpenIdProviderConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleIdentityStsV1OpenIdProviderConfig
Returns a new instance of GoogleIdentityStsV1OpenIdProviderConfig.
527 528 529 |
# File 'lib/google/apis/sts_v1/classes.rb', line 527 def initialize(**args) update!(**args) end |
Instance Attribute Details
#authorization_endpoint ⇒ String
URL pointing to an authorization endpoint under this issuer. Note: Currently
this endpoint returns a 404.
Corresponds to the JSON property authorization_endpoint
489 490 491 |
# File 'lib/google/apis/sts_v1/classes.rb', line 489 def @authorization_endpoint end |
#id_token_signing_alg_values_supported ⇒ Array<String>
JSON array containing a list of the JWS signing algorithms (alg values)
supported by the OP for the ID token to encode the claims in a JWT [JWT]. Note:
Currently always "["RS256"]".
Corresponds to the JSON property id_token_signing_alg_values_supported
496 497 498 |
# File 'lib/google/apis/sts_v1/classes.rb', line 496 def id_token_signing_alg_values_supported @id_token_signing_alg_values_supported end |
#issuer ⇒ String
URL using the https scheme with no query or fragment components that the OP
asserts as its issuer identifier.
Corresponds to the JSON property issuer
502 503 504 |
# File 'lib/google/apis/sts_v1/classes.rb', line 502 def issuer @issuer end |
#jwks_uri ⇒ String
URL of the OP's JWK Set [JWK] document, which MUST use the https scheme.
Corresponds to the JSON property jwks_uri
507 508 509 |
# File 'lib/google/apis/sts_v1/classes.rb', line 507 def jwks_uri @jwks_uri end |
#response_types_supported ⇒ Array<String>
JSON array containing a list of the OAuth 2.0 response_type values that this
OP supports. Note: Currently always "["id_token"]".
Corresponds to the JSON property response_types_supported
513 514 515 |
# File 'lib/google/apis/sts_v1/classes.rb', line 513 def response_types_supported @response_types_supported end |
#subject_types_supported ⇒ Array<String>
JSON array containing a list of the subject identifier types that this OP
supports. Note: Currently always "["public"]".
Corresponds to the JSON property subject_types_supported
519 520 521 |
# File 'lib/google/apis/sts_v1/classes.rb', line 519 def subject_types_supported @subject_types_supported end |
#token_endpoint ⇒ String
URL pointing to a token endpoint under this issuer. Note: Currently this
endpoint returns a 404.
Corresponds to the JSON property token_endpoint
525 526 527 |
# File 'lib/google/apis/sts_v1/classes.rb', line 525 def token_endpoint @token_endpoint end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
532 533 534 535 536 537 538 539 540 |
# File 'lib/google/apis/sts_v1/classes.rb', line 532 def update!(**args) @authorization_endpoint = args[:authorization_endpoint] if args.key?(:authorization_endpoint) @id_token_signing_alg_values_supported = args[:id_token_signing_alg_values_supported] if args.key?(:id_token_signing_alg_values_supported) @issuer = args[:issuer] if args.key?(:issuer) @jwks_uri = args[:jwks_uri] if args.key?(:jwks_uri) @response_types_supported = args[:response_types_supported] if args.key?(:response_types_supported) @subject_types_supported = args[:subject_types_supported] if args.key?(:subject_types_supported) @token_endpoint = args[:token_endpoint] if args.key?(:token_endpoint) end |