Class: Google::Apis::StsV1::GoogleIdentityStsV1betaOptions
- Inherits:
-
Object
- Object
- Google::Apis::StsV1::GoogleIdentityStsV1betaOptions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sts_v1/classes.rb,
lib/google/apis/sts_v1/representations.rb,
lib/google/apis/sts_v1/representations.rb
Overview
An Options object configures features that the Security Token Service
supports, but that are not supported by standard OAuth 2.0 token exchange
endpoints, as defined in https://tools.ietf.org/html/rfc8693.
Instance Attribute Summary collapse
-
#access_boundary ⇒ Google::Apis::StsV1::GoogleIdentityStsV1betaAccessBoundary
An access boundary defines the upper bound of what a principal may access.
-
#user_project ⇒ String
A Google project used for quota and billing purposes when the credential is used to access Google APIs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleIdentityStsV1betaOptions
constructor
A new instance of GoogleIdentityStsV1betaOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleIdentityStsV1betaOptions
Returns a new instance of GoogleIdentityStsV1betaOptions.
552 553 554 |
# File 'lib/google/apis/sts_v1/classes.rb', line 552 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_boundary ⇒ Google::Apis::StsV1::GoogleIdentityStsV1betaAccessBoundary
An access boundary defines the upper bound of what a principal may access. It
includes a list of access boundary rules that each defines the resource that
may be allowed as well as permissions that may be used on those resources.
Corresponds to the JSON property accessBoundary
542 543 544 |
# File 'lib/google/apis/sts_v1/classes.rb', line 542 def access_boundary @access_boundary end |
#user_project ⇒ String
A Google project used for quota and billing purposes when the credential is
used to access Google APIs. The provided project overrides the project bound
to the credential. The value must be a project number or a project ID. Example:
my-sample-project-191923. The maximum length is 32 characters.
Corresponds to the JSON property userProject
550 551 552 |
# File 'lib/google/apis/sts_v1/classes.rb', line 550 def user_project @user_project end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
557 558 559 560 |
# File 'lib/google/apis/sts_v1/classes.rb', line 557 def update!(**args) @access_boundary = args[:access_boundary] if args.key?(:access_boundary) @user_project = args[:user_project] if args.key?(:user_project) end |